@@ -16,24 +16,20 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: Yelper.h,v 1.2 2005/12/11 22:28:54 dscorgie Exp $
+ *  $Id: Yelper.h,v 1.3 2006/06/10 23:19:28 chpe Exp $
  */
 
 #ifndef __YELPER_H__
 #define __YELPER_H__
 
 #include <gtkmozembed.h>
-
 #include <nsCOMPtr.h>
-#include <nsIWebBrowser.h>
-#include <nsIDOMWindow.h>
-#ifdef TYPEAHEADFIND
-#include <nsITypeAheadFind.h>
-#else
-#include <nsIWebBrowserFind.h>
-#endif
-#include <nsIPrintSettings.h>
-#include <yelp-print.h>
+
+#include "yelp-print.h"
+
+class nsIDOMWindow;
+class nsITypeAheadFind;
+class nsIWebBrowser;
 
 class Yelper
 {
@@ -65,13 +61,7 @@ private:
 	GtkMozEmbed *mEmbed;
 	nsCOMPtr<nsIWebBrowser> mWebBrowser;
 	nsCOMPtr<nsIDOMWindow> mDOMWindow;
-#ifdef TYPEAHEADFIND
 	nsCOMPtr<nsITypeAheadFind> mFinder;
-#else
-	nsCOMPtr<nsIWebBrowserFind> mFinder;
-#endif
-
-	void SetPrintSettings (YelpPrintInfo *settings, nsIPrintSettings *target);
 };
 
 #endif /* !__YELPER_H__ */
