@@ -76,7 +76,8 @@ yelp_io_channel_new_file (gchar    *file,
     YelpIOChannel *channel;
     GIOChannel    *iochannel;
 
-    g_return_val_if_fail (file != NULL, NULL);
+    if (!file)
+    	return NULL;
 
     channel = g_new0(YelpIOChannel, 1);
     iochannel = (GIOChannel *) channel;
@@ -96,14 +97,16 @@ yelp_io_channel_new_file (gchar    *file,
 	yelp_io_free (iochannel);
 	channel = (YelpIOChannel *) g_io_channel_new_file (file, "r", error);
 
-	if (error)
-	    g_set_error (error, YELP_ERROR, YELP_ERROR_IO,
-			 _("The file ‘%s’ could not be read and decoded. "
-			   "The file may be compressed in an unsupported "
-			   "format."),
-			 file);
-	return NULL;
-
+	if (!channel) {
+	    if (error) {
+		    g_set_error (error, YELP_ERROR, YELP_ERROR_IO,
+				 _("The file ‘%s’ could not be read and decoded. "
+				   "The file may be compressed in an unsupported "
+				   "format."),
+				 file);
+	    }
+	    return NULL;
+	}
     }
 
     iochannel->is_readable  = TRUE;
@@ -168,11 +171,6 @@ yelp_io_free          (GIOChannel    *channel)
 {
     YelpIOChannel *yelp_channel = (YelpIOChannel *) channel;
 
-#ifdef HAVE_LIBBZ2
-    if (yelp_channel->bzin)
-	g_free (yelp_channel->bzin);
-#endif
-
     g_free (yelp_channel);
 }
 
